@@ -50,7 +50,7 @@ class Path(Drawable):
         self.arrows = arrows or []
 
     def __repr__(self):
-        return "<Path(%s, %s)>" % (self.__class__.__name__, self.points, self.style)
+        return "<Path(%s, %s)>" % (self.points, self.style)
 
     def extents(self):
         xs, ys = zip(*self.points)
